import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import styles from './Crypto.scss';
import gaDataset from '../../utils/gaDataset';

const cx = classNames.bind(styles);
const COMPANIGN_URL = 'https://campaign.cnyes.com/topics/crypto1022';

const renderCompanyLogo = id => {
  return <img src={`${COMPANIGN_URL}/assets/logo-${id}.png`} alt="" />;
};

const renderSymbolIcon = symbol => {
  return <img src={`${COMPANIGN_URL}/assets/crypto-${symbol}.svg`} alt="" />;
};

const Card = ({ data, type }) => {
  const { id, title, link, gaEvent = null, description, features, performance } = data;
  const isLarge = type === 'large';
  const cardTypeStyle = isLarge ? 'card-content--large' : 'card-content--small';
  const isPionex = id === 'pionex';
  const isBinance = id === 'binance';

  const renderFeatures = () => (
    <div className={cx('card-features')}>
      {features.map(feature => (
        <div className={cx('card-feature')} key={feature.title}>
          <img src={feature.logo} alt="feature logo" />
          <p className={cx('card-feature--title')}>{feature.title}</p>
          <p className={cx({ 'pionex-theme': isPionex }, { 'binance-theme': isBinance })}>{feature.subTitle}</p>
          <p className={cx('card-feature--description')}>{feature.description}</p>
        </div>
      ))}
    </div>
  );

  const renderTable = () => (
    <table>
      <thead>
        <tr>{performance && performance.headers.map(header => <th key={header}>{header}</th>)}</tr>
      </thead>
      <tbody>
        {performance &&
          performance.rows.map(({ symbol, value, day, tag }, idx) => {
            return (
              <tr key={`row-${idx.toString()}`}>
                <td>
                  {renderSymbolIcon(symbol.toLowerCase())}
                  <span>{symbol}</span>
                  {tag && <span className={cx('symbol-tag')}>{tag}</span>}
                </td>
                <td>{value}</td>
                <td>{day}</td>
              </tr>
            );
          })}
      </tbody>
    </table>
  );

  return (
    <a className={cx('card')} href={link} rel="noopener noreferrer" target="_blank" {...gaDataset(gaEvent)}>
      <div className={cx('card-header')}>
        {renderCompanyLogo(id)}
        <span className={cx('card-header--title')}>{title}</span>
        {description && <span className={cx('card-header--description')}>{description}</span>}
      </div>
      <div className={cx('card-content', cardTypeStyle)}>{isLarge ? renderFeatures() : renderTable()}</div>
    </a>
  );
};

Card.propTypes = {
  data: {
    id: PropTypes.oneOf('pionex', 'binance', 'ace', 'bincentive', 'pokket'),
    title: PropTypes.string,
    link: PropTypes.string,
    gaEvent: PropTypes.object,
    description: PropTypes.oneOfType(PropTypes.string, null),
    features: {
      title: PropTypes.string,
      subTitle: PropTypes.string,
      description: PropTypes.string,
    },
    performance: {
      headers: PropTypes.array,
      rows: PropTypes.arrayOf({
        symbol: PropTypes.string,
        value: PropTypes.string,
        day: PropTypes.string,
      }),
    },
  },
  type: PropTypes.oneOf(['large', 'small']),
};
Card.defaultProps = {
  data: {},
  type: 'small',
};

export default Card;
