import React from 'react';
import classNames from 'classnames/bind';
import PropTypes from 'prop-types';
import styles from './Crypto.scss';
import Card from './Card';
import gaDataset from '../../utils/gaDataset';
import config from './config.json';

const cx = classNames.bind(styles);

const Crypto = ({ isShowHeader }) => {
  const { header, topGroup, bottomGroup } = config;
  const { title, readmore, gaEvent } = header;

  const renderHeader = (
    <div className={cx('crypto-header')}>
      <div className={cx('crypto-header--title')}>
        <a href={title.link} rel="noopener noreferrer" {...gaDataset(gaEvent.title)}>
          {title.name}
        </a>
      </div>
      <div className={cx('crypto-readmore')}>
        <span className={cx('crypto-readmore--updatetime')}>更新日期： {header.updatetime}</span>
        <a href={readmore.link} rel="noopener noreferrer" {...gaDataset(gaEvent.readmore)}>
          看更多
          <span>&gt;</span>
        </a>
      </div>
    </div>
  );

  return (
    <div className={cx('crypto')}>
      {isShowHeader && renderHeader}

      <div className={cx('crypto-content')}>
        {topGroup.map(company => <Card data={company} type="large" key={company.id} />)}
        {bottomGroup.map(company => <Card data={company} type="small" key={company.id} />)}
      </div>
    </div>
  );
};

Crypto.propTypes = {
  isShowHeader: PropTypes.bool,
};

Crypto.defaultProps = {
  isShowHeader: true,
};

export default Crypto;
