/* eslint-disable no-unused-expressions */
import React, { useState, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import DialogButton from './DialogButton';
import styles from './Dialog.scss';
import CloseIcon from '../../assets/icon-toast-close.svg';

export const THEME = {
  NORMAL: 'normal',
  ANUE: 'anue',
};

const cx = classNames.bind(styles);

const Dialog = ({
  title,
  visible,
  width,
  height,
  footer,
  needClose,
  maskClosable,
  className,
  styleType,
  children,
  onClose,
}) => {
  const wrapperRef = useRef();
  const [isOpen, setIsOpen] = useState(visible);

  useEffect(
    () => {
      setIsOpen(visible);
    },
    [visible]
  );

  const close = () => {
    setIsOpen(false);
    onClose && onClose();
  };

  const maskCloseHandler = e => {
    e.stopPropagation();
    e.nativeEvent.stopImmediatePropagation();

    if (maskClosable && wrapperRef.current === e.target) {
      maskClosable && close();
    }
  };

  const buttonClickHandler = () => close();

  const footerBar = !footer ? (
    <DialogButton onClick={buttonClickHandler} theme={styleType}>
      我知道了
    </DialogButton>
  ) : (
    footer
  );

  const dialogSize = {
    maxWidth: `${width}px`,
    minHeight: `${height - 38 - 16 * 2}px`,
  };

  return (
    <div ref={wrapperRef} className={cx('wrapper', isOpen ? 'visible' : 'invisible')} onClick={maskCloseHandler}>
      <div className={cx('dialog', className)} style={dialogSize}>
        {(title || needClose) && (
          <div className={cx('dialog__header')}>
            <h3>{title}</h3>
            <img src={CloseIcon} onClick={buttonClickHandler} alt="Close" />
          </div>
        )}
        <div className={cx('dialog__content')}>{children}</div>
        <div className={cx('dialog__footer')}>{footerBar}</div>
      </div>
    </div>
  );
};

Dialog.propTypes = {
  children: PropTypes.oneOfType([PropTypes.element, PropTypes.arrayOf(PropTypes.element)]),
  title: PropTypes.string,
  visible: PropTypes.bool,
  width: PropTypes.number,
  height: PropTypes.number,
  footer: PropTypes.element,
  needClose: PropTypes.bool,
  maskClosable: PropTypes.bool,
  className: PropTypes.string,
  styleType: PropTypes.oneOf([THEME.NORMAL, THEME.ANUE]),
  onClose: PropTypes.func,
};

Dialog.defaultProps = {
  children: null,
  title: '',
  visible: false,
  width: 400,
  height: 300,
  footer: null,
  needClose: true,
  maskClosable: true,
  className: '',
  styleType: THEME.ANUE,
  onClose: () => {},
};

export default Dialog;
export { DialogButton };
