import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import AnueNavigator from '../AnueNavigator/Hook/AnueNavigator';
import AnueAccount from '../AnueAccount/AnueAccount';
import AnueLink from '../../utils/anueLink';
import { navsType } from '../../utils/propTypes';
import styles from './StaticHeader.scss';

const cx = classNames.bind(styles);

export default class StaticHeader extends Component {
  static propTypes = {
    navs: navsType.isRequired,
    channelName: PropTypes.string.isRequired,
    apiEnv: PropTypes.string,
  };

  static defaultProps = {
    apiEnv: 'prod',
  };

  constructor(props) {
    super(props);

    this.anueUrl = new AnueLink(props.apiEnv);
  }

  render() {
    const { navs, channelName, apiEnv } = this.props;

    return (
      <div id="cnyes-header-wrapper" data-channel={channelName}>
        <div className={cx('desktop-header')}>
          <AnueNavigator
            channelName={channelName}
            logoUrl={this.anueUrl.wwwChannelLink}
            enableSearchBar
            navs={navs}
            apiEnv={apiEnv}
            dataPrefix={['global']}
            accountComponent={
              <AnueAccount
                enableStatic
                onLogin={this.anueUrl.loginLink}
                onRegister={this.anueUrl.loginLink}
                isLogin={false}
              />
            }
          />
        </div>
        <div className="mobile-header-placeholder" />
      </div>
    );
  }
}
