import { useState, useEffect } from 'react';
import Cookies from 'universal-cookie';

const cookies = new Cookies();

function useCookie(key, initialValue) {
  const [item, setInnerValue] = useState(() => {
    return cookies.get(key) || initialValue;
  });

  const setValue = (value, options) => {
    setInnerValue(value);
    cookies.set(key, value, options);
  };

  const removeKey = () => {
    cookies.remove(key);
  };

  // 補一個addChangeListener, 監聽cookie變化
  useEffect(() => {
    const handelCookieChange = argument => {
      if (argument.name === key) {
        setInnerValue(argument.value);
      }
    };

    // `addChangeListener(callback)`
    // Add a listener to when a cookie is set or removed.
    // callback (function): Call that will be called with the first argument containing name, value and options of the changed cookie.
    cookies.addChangeListener(handelCookieChange);

    // `removeChangeListener(callback)`
    // Remove a listener from the change callback.
    return () => cookies.removeChangeListener(handelCookieChange);
  }, []);

  return [item, setValue, removeKey];
}

export default useCookie;
